---
jupytext:
  formats: ipynb,md:myst
  text_representation:
    extension: .md
    format_name: myst
    format_version: 0.16
    jupytext_version: 1.14.1
kernelspec:
  display_name: Python 3
  language: python
  name: python3
---

# SPICE aberration corrections

In order to simplify the use of the SPICE aberration corrections, we introduced a `SpiceAbCorr` object:

```{code-cell}
from planetary_coverage.spice import SpiceAbCorr
```

It will check that the provided values are valid:

```{code-cell}
SpiceAbCorr()
```
```{code-cell}
SpiceAbCorr('LT')
```
```{code-cell}
SpiceAbCorr('XCN+S')
```
```{code-cell}
:tags: [raises-exception]
SpiceAbCorr('FOO')
```

You can restrict the list of the valid keys if you need to:

```{code-cell}
SpiceAbCorr('LT', restrict=('LT', 'LT+S'))
```
```{code-cell}
:tags: [raises-exception]
SpiceAbCorr('CN', restrict=('LT', 'LT+S'))
```

To be fully compatible with `spiceypy`, it extends directly from the python base class `str`:

```{code-cell}
abcorr = SpiceAbCorr('LT+S')

isinstance(abcorr, str)
```
```{code-cell}
abcorr == 'LT+S'
```

with a few additional properties:

```{code-cell}
abcorr.reception
```
```{code-cell}
abcorr.transmission
```
```{code-cell}
abcorr.stellar
```
```{code-cell}
abcorr.oneway
```
```{code-cell}
abcorr.converged
```

Finally, you can apply the light time correction based on the provided key:

```{code-cell}
et, lt = 10, 2

abcorr = SpiceAbCorr('NONE')
abcorr(et, lt)  # NONE -> et (no correction)
```
```{code-cell}
abcorr = SpiceAbCorr('LT')
abcorr(et, lt)  # LT -> et - lt (reception)
```
```{code-cell}
abcorr = SpiceAbCorr('XLT')
abcorr(et, lt)  # XLT -> et + lt (transmission)
```
