---
jupytext:
  formats: ipynb,md:myst
  text_representation:
    extension: .md
    format_name: myst
    format_version: 0.16
    jupytext_version: 1.14.1
kernelspec:
  display_name: Python 3
  language: python
  name: python3
---

```{code-cell}
:tags: ["remove-cell"]

! rm -rf lsk/ mk/ kernels/
```

# SPICE download CLI

In order to simply the kernel management, the `planetary-coverage` provides 2 command line interface (CLI):
- `kernel-download` to download one or more kernels from a SPICE registry.
- `mk-download` to download all the missing kernels listed in a metakernel.

These two commands are available in Jupyter notebooks or directly in your terminal.

## Kernel download CLI

:::{Hint}
:class: margin

Remove the `!` symbol to run this command in your terminal.
But keep it if you run this cell into a Jupyter notebook.

:::

```{code-cell}
!kernel-download --help
```

For example, to download the leapseconds kernel from NAIF generic kernels you can do:

```{code-cell}
!kernel-download lsk/naif0012.tls
```

You can provide a specific mission name to select an other SPICE registry:

:::{Tip}
:class: margin

You can list more than one kernel.
:::

```{code-cell}
!kernel-download --esa JUICE mk/juice_crema_3_0.tm mk/juice_crema_5_0.tm
```

If you don't provide any kernel, you will get the URL of the SPICE registry:

```{code-cell}
!kernel-download --esa JUICE
```



## Metakernel download CLI

```{code-cell}
!mk-download --help
```

If you already have a metakernel, you can download all its missing kernels
that are not present locally. Here we will use [a simple metakernel](metakernel.tm):

```{code-cell}
!cat metakernel.tm
```

We can see that the default SPICE registry is described in the file header
(`https://naif.jpl.nasa.gov/pub/naif/generic_kernels/`) so we don't need to specify
an explicit `--remote` endpoint. However, we would like to store the kernels into a
`kernels/` folder and not in the default `.` location so we will add a `--kernels-dir`
parameter:

```{code-cell}
!mk-download --kernels-dir kernels metakernel.tm
```

As you can see the files were correctly downloaded:

```{code-cell}
!ls kernels/*/*
```


```{code-cell}
:tags: ["remove-cell"]

! rm -rf lsk/ mk/
```
