"""Test CLI metakernel module."""

import sys

import planetary_coverage.cli.metakernel as mk_module
from planetary_coverage.cli import cli_metakernel_download


def test_cli_metakernel(monkeypatch, capsys):
    """Test CLI metakernel."""

    class MockMetakernel:
        """Mock Metakernel object."""

        def __init__(self, mk, **kwargs):
            sys.stdout.write(f'{mk} {kwargs}')

    monkeypatch.setattr(mk_module, 'MetaKernel', MockMetakernel)

    # Single mk provided
    cli_metakernel_download(['foo.mk'])
    assert capsys.readouterr().out == "foo.mk {'download': True}"

    # Add custom remote
    cli_metakernel_download(['--remote', 'https://example.org', 'foo.mk'])
    assert (
        capsys.readouterr().out
        == "foo.mk {'download': True, 'remote': 'https://example.org'}"
    )

    # Add custom kernels location
    cli_metakernel_download(['--kernels-dir', 'kernels/', 'foo.mk'])
    assert capsys.readouterr().out == "foo.mk {'download': True, 'kernels': 'kernels/'}"
