"""Test ESA event file module."""

from pathlib import Path

import numpy as np

from planetary_coverage import read_events
from planetary_coverage.events import CsvEventsFile


DATA = Path(__file__).parent / '..' / 'data'


def test_esa_events_phases():
    """Test ESA events mission phases."""
    phases = read_events(DATA / 'mission_phases.csv')

    assert len(phases) == 4  # number of events
    assert phases.start == np.datetime64('2031-01-19T18:50:41')
    assert phases.stop == np.datetime64('2035-10-05T16:01:00')

    assert 'GCO500' in phases


def test_esa_events_timeline():
    """Test ESA events mission timeline."""
    timeline = read_events(DATA / 'mission_timeline.csv')

    assert len(timeline) == 11  # number of events != number of rows

    assert timeline.start == np.datetime64('2031-01-20T06:31:08')
    assert timeline.stop == np.datetime64('2032-02-15T06:07:11')

    assert 'FLYBY_GANYMEDE' in timeline


def test_esa_events_sequence():
    """Test ESA events mission sequence."""
    # Generic input with a known header and multiple keys
    phases = read_events(DATA / 'mission_phases.csv')

    assert isinstance(phases, CsvEventsFile)
    assert len(phases) == 4

    assert 'GCO500' in phases

    assert phases.start == np.datetime64('2031-01-19T18:50:41')
    assert phases.stop == np.datetime64('2035-10-05T16:01:00')

    # Generic input with an unknown header and a single key (repeated)
    downlinks = read_events(DATA / 'downlink_visibility.csv')

    assert isinstance(downlinks, CsvEventsFile)
    assert len(downlinks) == 1

    assert 'DL_' in downlinks

    assert downlinks.start == np.datetime64('2034-12-19T17:55:17')
    assert downlinks.stop == np.datetime64('2035-09-28T11:38:51')

    for downlink in downlinks['DL_']:
        assert downlink.start == np.datetime64('2034-12-19T17:55:17')
        assert downlink.stop == np.datetime64('2034-12-20T04:10:31')
        break
