"""Test HTML formatter module."""

from pytest import raises

from planetary_coverage.html import Html, display_html, table, tag


def test_html_tag():
    """Test HTML tag formatter."""
    assert tag('br') == '<br/>'
    assert tag('a', 'foo') == '<a>foo</a>'
    assert tag('a', 'foo', href='bar') == '<a href="bar">foo</a>'
    assert tag('img', src='foo') == '<img src="foo"/>'
    assert tag('th', '') == '<th></th>'


def test_html_table():
    """Test HTML table formatter."""
    assert table('1') == '<table><tr><td>1</td></tr></table>'
    assert table(2) == '<table><tr><td>2</td></tr></table>'
    assert table(3.4) == '<table><tr><td>3.4</td></tr></table>'

    assert table('foo', id='bar') == '<table id="bar"><tr><td>foo</td></tr></table>'

    assert table(['1', 2, 3.4]) == (
        '<table><tr><td>1</td><td>2</td><td>3.4</td></tr></table>'
    )

    assert table([['1', 2, 3.4]]) == (
        '<table><tr><td>1</td><td>2</td><td>3.4</td></tr></table>'
    )

    assert table([['1'], [2], [3.4]]) == (
        '<table>'
        '<tr><td>1</td></tr>'
        '<tr><td>2</td></tr>'
        '<tr><td>3.4</td></tr>'
        '</table>'
    )

    assert table([['1', 2, 3.4], ['a', 'b', 'c']]) == (
        '<table>'
        '<tr><td>1</td><td>2</td><td>3.4</td></tr>'
        '<tr><td>a</td><td>b</td><td>c</td></tr>'
        '</table>'
    )

    assert table(['1', 2, 3.4], header=('', '6', 7.8)) == (
        '<table><thead>'
        '<tr><th></th><th>6</th><th>7.8</th></tr>'
        '</thead><tbody>'
        '<tr><td>1</td><td>2</td><td>3.4</td></tr>'
        '</tbody></table>'
    )

    assert table([['2', 4, 7.8], ['a', 'b', 'c']], header=('1', 3, 5.6)) == (
        '<table><thead>'
        '<tr><th>1</th><th>3</th><th>5.6</th></tr>'
        '</thead><tbody>'
        '<tr><td>2</td><td>4</td><td>7.8</td></tr>'
        '<tr><td>a</td><td>b</td><td>c</td></tr>'
        '</tbody></table>'
    )

    assert table({'1': '2', 3: 4, 5.6: 7.8}) == (
        '<table><thead>'
        '<tr><th>1</th><th>3</th><th>5.6</th></tr>'
        '</thead><tbody>'
        '<tr><td>2</td><td>4</td><td>7.8</td></tr>'
        '</tbody></table>'
    )

    assert table({'1': ['2', 'a'], 3: [4, 'b'], 5.6: [7.8, 'c']}) == (
        '<table><thead>'
        '<tr><th>1</th><th>3</th><th>5.6</th></tr>'
        '</thead><tbody>'
        '<tr><td>2</td><td>4</td><td>7.8</td></tr>'
        '<tr><td>a</td><td>b</td><td>c</td></tr>'
        '</tbody></table>'
    )

    with raises(TypeError):
        _ = table([[[1]]])


def test_html_repr():
    """Test HTML representation."""
    assert display_html(Html('<h1>Foo</h1>')) == '<h1>Foo</h1>'
