"""Test filesize module."""

from pathlib import Path

from pytest import raises

from planetary_coverage.misc import file_size
from planetary_coverage.misc.filesize import as_bytes


DATA = (Path(__file__).parent / '..' / 'data').resolve()


def test_filesize_as_bytes():
    """Test filesize as bytes conversion."""
    assert as_bytes(0) == '0 B'
    assert as_bytes(1) == '1 B'
    assert as_bytes(2048) == '2 kB'
    assert as_bytes(3 * 2**20) == '3 MB'
    assert as_bytes(4 * 2**30) == '4 GB'
    assert as_bytes(5 * 2**40) == '5 TB'
    assert as_bytes(6 * 2**50) == '6 PB'
    assert as_bytes(2**60) == '1,024 PB'

    # Precision format .01f by default
    assert as_bytes(1023) == '1,023 B'
    assert as_bytes(1025) == '1 kB'
    assert as_bytes(1023.9, fmt='.3f') == '1023.900 B'


def test_filesize_getter():
    """Test filesize getter."""
    assert file_size(DATA / 'dummy.tpc') == '722 B'
    assert file_size(DATA / 'mission_phases.csv') == '330 B'

    # Combined sizes
    assert (
        file_size(
            DATA / 'dummy.tpc',
            DATA / 'mission_phases.csv',
        )
        == '1 kB'
    )

    # Empty
    assert file_size() == '0 B'

    # Not a file
    with raises(FileNotFoundError):
        _ = file_size(DATA)

    # File not found
    with raises(FileNotFoundError):
        _ = file_size(DATA / 'foo.bar')

    assert file_size(DATA / 'foo.bar', skip=True) == '0 B'
