"""Test miscellaneous logger module."""

import logging

from planetary_coverage.misc import logger


def test_custom_logger(capsys):
    """Test custom logger."""
    log, log_debugger = logger('Test logger')

    log.debug('debug message')
    log.info('info message')
    log.warning('warning message')
    log.error('error message')
    log.critical('critical message')

    out, err = capsys.readouterr()
    assert not out
    assert err == (
        '[Test logger] warning message\n'
        '[Test logger] error message\n'
        '[Test logger] critical message\n'
    )

    # Enable debug mode
    log_debugger()

    out, err = capsys.readouterr()
    assert not out
    assert err == '[Test logger] Change logger level to DEBUG\n'

    log.debug('debug message')
    log.info('info message')
    log.warning('warning message')
    log.error('error message')
    log.critical('critical message')

    out, err = capsys.readouterr()
    assert not out
    assert err == (
        '[Test logger] debug message\n'
        '[Test logger] info message\n'
        '[Test logger] warning message\n'
        '[Test logger] error message\n'
        '[Test logger] critical message\n'
    )

    # Enable debug mode with INFO level
    log_debugger('info')

    out, err = capsys.readouterr()
    assert not out
    assert err == '[Test logger] Change logger level to INFO\n'

    log.debug('debug message')
    log.info('info message')
    log.warning('warning message')
    log.error('error message')
    log.critical('critical message')

    out, err = capsys.readouterr()
    assert not out
    assert err == (
        '[Test logger] info message\n'
        '[Test logger] warning message\n'
        '[Test logger] error message\n'
        '[Test logger] critical message\n'
    )

    # Disable debug mode
    log_debugger(False)

    out, err = capsys.readouterr()
    assert not out
    assert not err

    log.debug('debug message')
    log.info('info message')
    log.warning('warning message')
    log.error('error message')
    log.critical('critical message')

    out, err = capsys.readouterr()
    assert not out
    assert err == (
        '[Test logger] warning message\n'
        '[Test logger] error message\n'
        '[Test logger] critical message\n'
    )


def test_custom_logger_info(capsys):
    """Test custom logger with INFO in stdout."""
    log, log_debugger = logger('Test logger', info_stdout=True)

    log.debug('debug message')
    log.info('info message')
    log.warning('warning message')
    log.error('error message')
    log.critical('critical message')

    out, err = capsys.readouterr()
    assert out == '[Test logger] info message\n'
    assert err == (
        '[Test logger] warning message\n'
        '[Test logger] error message\n'
        '[Test logger] critical message\n'
    )

    # Enable debug
    log_debugger(True)
    assert log.level == logging.DEBUG

    # Debug with a warning level
    log_debugger('warning')
    assert log.level == logging.WARNING

    # Disable debug and change the level to the default value
    log_debugger(False)
    assert log.level == logging.INFO
