"""Test miscellaneous segment module."""

import numpy as np
from numpy.testing import assert_array_almost_equal as assert_array

from planetary_coverage.misc import Segment


def test_segment_codes():
    """Test segment codes."""
    assert Segment.OUT == 0
    assert Segment.IN == 1
    assert Segment.START == 2
    assert Segment.STOP == 3
    assert Segment.SINGLE == 4


def test_segment_attr():
    """Test segment attributes."""
    arr = [False, True, True, True, False, False, True, False, True, True]

    seg = Segment(arr)

    assert_array(
        seg.codes,
        [
            Segment.OUT,
            Segment.START,
            Segment.IN,
            Segment.STOP,
            Segment.OUT,
            Segment.OUT,
            Segment.SINGLE,
            Segment.OUT,
            Segment.START,
            Segment.STOP,
        ],
    )

    assert_array(
        seg.starts, [False, True, False, False, False, False, True, False, True, False]
    )

    assert_array(
        seg.stops, [False, False, False, True, False, False, True, False, False, True]
    )

    assert_array(
        seg.singles, [False, False, False, False, False, False, True, False, False, False]
    )

    assert_array(seg.inside, arr)
    assert_array(seg.outside, np.invert(arr))

    # __len__
    assert len(seg) == 3

    # Indexes
    assert_array(seg.istarts, [1, 6, 8])
    assert_array(seg.istops, [3, 6, 9])

    # Iter
    for s, res in zip(seg, [slice(1, 4), slice(6, 7), slice(8, 10)]):
        assert s == res
        assert all(arr[s])
