"""Test SPICE kernel module."""

from pathlib import Path

from planetary_coverage.spice.kernel import get_details, get_summary, get_type


DATA = (Path(__file__).parent / '..' / 'data').resolve()


def test_kernel_type():
    """Test kernel type getter."""
    assert get_type('foo.bc') == '📷 CK'
    assert get_type('bar.tm') == '📚 MK'
    assert get_type('baz.tls') == '⏱️ LSK'
    assert get_type('foo.bar') == '❓ UNKNOWN'

    # Optional default
    assert get_type('foo.bar', default_txt='BAZ', default_icon='⚠️') == '⚠️ BAZ'
    assert get_type('foo.bar', default_txt='') == '❓'  # stripped (no text)
    assert get_type('foo.bar', default_icon='') == 'UNKNOWN'  # stripped (no icon)


def test_kernels_summary():
    """Test kernels summary."""
    assert get_summary([
        DATA / 'dummy.ti',
        DATA / 'dummy.tpc',
        DATA / 'dummy.tsc',
        DATA / 'dummy.tsc',
    ]) == {
        'Types': ['🔬 IK', '🪐 PCK', '🛰️ SCLK', '<b>Total</b>'],
        'Count': [1, 1, 2, 4],
        'Size': ['7 kB', '722 B', '3 kB', '11 kB'],
    }


def test_kernels_details():
    """Test kernels summary."""
    assert get_details([
        DATA / 'dummy.ti',
        DATA / 'dummy.tpc',
        DATA / 'dummy.tsc',
        DATA / 'dummy.tsc',
    ]) == {
        'Kernels': [
            DATA / 'dummy.ti',
            DATA / 'dummy.tpc',
            DATA / 'dummy.tsc',
            DATA / 'dummy.tsc',
        ],
        'Type': ['🔬 IK', '🪐 PCK', '🛰️ SCLK', '🛰️ SCLK'],
        'Size': ['7 kB', '722 B', '1 kB', '1 kB'],
    }
